@@ -1,4 +1,4 @@
-use lspower::lsp;
+use tower_lsp::lsp_types;
 
 #[derive(Clone)]
 pub struct Document {
@@ -7,7 +7,7 @@ pub struct Document {
 }
 
 impl Document {
-    pub fn open(params: lsp::DidOpenTextDocumentParams) -> Self {
+    pub fn open(params: lsp_types::DidOpenTextDocumentParams) -> Self {
         let content = ropey::Rope::from(params.text_document.text);
         let content = content;
         Self { content }
