@@ -1,7 +1,4 @@
+pub mod completion;
 /// Provider definitions for LSP `textDocument/publishDiagnostics`.
 pub mod diagnostics;
-pub use diagnostics::*;
-pub mod completion;
-pub use completion::*;
 pub mod formatting;
-pub use formatting::*;
