@@ -1,12 +1,12 @@
 use crate::core;
 use dashmap::DashMap;
 use log::debug;
-use lspower::lsp;
 use std::path::Path;
 use tokio::process::Command;
+use tower_lsp::lsp_types;
 
 pub struct DiagnosticData {
-    current_diagnostics: DashMap<lsp::Url, Vec<lsp::Diagnostic>>,
+    current_diagnostics: DashMap<lsp_types::Url, Vec<lsp_types::Diagnostic>>,
 }
 impl DiagnosticData {
     pub fn new() -> Self {
@@ -15,7 +15,7 @@ impl DiagnosticData {
         }
     }
 
-    pub fn update(&self, data: DashMap<lsp::Url, Vec<lsp::Diagnostic>>) {
+    pub fn update(&self, data: DashMap<lsp_types::Url, Vec<lsp_types::Diagnostic>>) {
         self.current_diagnostics.clear();
         for it in data.iter() {
             self.current_diagnostics.insert(it.key().clone(), it.value().clone());
@@ -29,7 +29,7 @@ pub async fn diagnostics(
     beancount_data: &core::BeancountData,
     bean_check_cmd: &Path,
     root_journal_file: &Path,
-) -> DashMap<lsp::Url, Vec<lsp::Diagnostic>> {
+) -> DashMap<lsp_types::Url, Vec<lsp_types::Diagnostic>> {
     let error_line_regexp = regex::Regex::new(r"^([^:]+):(\d+):\s*(.*)$").unwrap();
 
     debug!("providers::diagnostics");
@@ -45,26 +45,26 @@ pub async fn diagnostics(
         debug!("bean-check generating diags");
         let output = std::str::from_utf8(&output.stderr).map_err(core::Error::from);
 
-        let map: DashMap<lsp::Url, Vec<lsp::Diagnostic>> = DashMap::new();
+        let map: DashMap<lsp_types::Url, Vec<lsp_types::Diagnostic>> = DashMap::new();
 
         for line in output.unwrap().lines() {
             debug!("line: {}", line);
             if let Some(caps) = error_line_regexp.captures(line) {
                 debug!("caps: {:?}", caps);
-                let position = lsp::Position {
+                let position = lsp_types::Position {
                     line: caps[2].parse::<u32>().unwrap().saturating_sub(1),
                     character: 0,
                 };
 
-                let file_url = lsp::Url::from_file_path(&caps[1]).unwrap();
-                let diag = lsp::Diagnostic {
-                    range: lsp::Range {
+                let file_url = lsp_types::Url::from_file_path(&caps[1]).unwrap();
+                let diag = lsp_types::Diagnostic {
+                    range: lsp_types::Range {
                         start: position,
                         end: position,
                     },
                     message: caps[3].trim().to_string(),
-                    severity: Some(lsp::DiagnosticSeverity::ERROR),
-                    ..lsp::Diagnostic::default()
+                    severity: Some(lsp_types::DiagnosticSeverity::ERROR),
+                    ..lsp_types::Diagnostic::default()
                 };
                 if map.contains_key(&file_url) {
                     map.get_mut(&file_url).unwrap().push(diag);
@@ -79,7 +79,7 @@ pub async fn diagnostics(
         DashMap::new()
     };
 
-    let ret: DashMap<lsp::Url, Vec<lsp::Diagnostic>> = DashMap::new();
+    let ret: DashMap<lsp_types::Url, Vec<lsp_types::Diagnostic>> = DashMap::new();
 
     // Add previous urls to clear out if neccessary
     for it in previous_diagnostics.current_diagnostics.iter() {
@@ -98,18 +98,18 @@ pub async fn diagnostics(
     // add flagged entries
     for uri in beancount_data.flagged_entries.iter() {
         for entry in uri.value().iter() {
-            let position = lsp::Position {
+            let position = lsp_types::Position {
                 line: entry.line,
                 character: 0,
             };
-            let diag = lsp::Diagnostic {
-                range: lsp::Range {
+            let diag = lsp_types::Diagnostic {
+                range: lsp_types::Range {
                     start: position,
                     end: position,
                 },
                 message: "Flagged".to_string(),
-                severity: Some(lsp::DiagnosticSeverity::WARNING),
-                ..lsp::Diagnostic::default()
+                severity: Some(lsp_types::DiagnosticSeverity::WARNING),
+                ..lsp_types::Diagnostic::default()
             };
             if ret.contains_key(uri.key()) {
                 ret.get_mut(uri.key()).unwrap().push(diag);
